# © 2024 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models


class FinancialContractGuaranteeLine(models.Model):
    _name = "financial.contract.guarantee.line"
    _description = "Financial contract guarantee line"
    _check_company_auto = True
    _rec_names_search = [
        "partner_id.name",
        "partner_id.member_number",
    ]
    _order = "line_date desc"

    guarantee_id = fields.Many2one(
        comodel_name="financial.contract.guarantee",
        string="Contrat de garantie",
        required=True,
        index=True,
    )
    partner_id = fields.Many2one(
        comodel_name="res.partner",
        related="guarantee_id.partner_id",
        string="Contact",
        store=True,
        index=True,
    )
    company_id = fields.Many2one(
        comodel_name="res.company",
        related="guarantee_id.company_id",
        string="Société",
        store=True,
        index=True,
    )
    currency_id = fields.Many2one(
        comodel_name="res.currency",
        related="guarantee_id.currency_id",
    )
    # Loan Data
    line_date = fields.Date("Date en cours")
    payment_date = fields.Date("Date de versement")
    amount_initial = fields.Monetary("Montant initial")
    amount_received = fields.Monetary("Montant reçu")
    end_date = fields.Date("Date de fin de prêt")
    remaining_capital = fields.Monetary("Capital restant dû")
    loan_duration = fields.Integer("Durée du crédit")
    guarantee_rate = fields.Float("Quotité garantie")
    guarantee_amount = fields.Monetary("En cours garanti")
    # Company Data
    segment_code = fields.Char("Code Segment")
    bdf_scoring = fields.Char("Cotation BDF")
    bdf_date = fields.Char("Date Cotation BDF")
    mcdo_scoring = fields.Char("Cotation MacDonough")
    mcdo_date = fields.Date("Date Cotation MacDonough")
    branch_code = fields.Char("Code branche")
    # Invoice Data
    commission_rate = fields.Float("Taux de commission")
    commission_amount = fields.Monetary("Montant de commission")
    commission_date_due = fields.Date("Echeance de commission")

    # ------------------------------------------------------
    # Constrains functions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD (Override ORM)
    # ------------------------------------------------------
