# Copyright 2023- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import fields, models


class ResPartner(models.Model):
    _inherit = "res.partner"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    financial_contract_guarantee_ids = fields.One2many(
        comodel_name="financial.contract.guarantee",
        inverse_name="partner_id",
        string="Contrats de garanties",
    )
    financial_contract_guarantee_count = fields.Integer(
        compute="_compute_financial_contract_guarantee_count"
    )

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    def _compute_financial_contract_guarantee_count(self):
        for partner in self:
            partner.financial_contract_guarantee_count = (
                partner.financial_contract_guarantee_ids.__len__()
            )

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------
    def action_view_contract_guarantee(self):
        self.ensure_one()
        return {
            "type": "ir.actions.act_window",
            "name": "Contrats de garantie",
            "res_model": "financial.contract.guarantee",
            "view_mode": "tree,form",
            "domain": [("partner_id", "=", self.id)],
            "flags": {"mode": "readonly"},
        }

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
